me.lomin.sayang


*activate*clj/s≠

clj

If true, register a function spec for every function defined with sdefn.

If true, register a function spec for every function defined with sdefn.
source (clj)source (cljs)raw docstring

activate!clj/s

(activate!)
source

activated?clj/s

(activated?)
source

deactivate!clj/smacro

(deactivate!)
source (clj)source (cljs)

ofclj/smacro

(of f)
source (clj)source (cljs)

sdefnclj/s≠macro

clj
(sdefn & defn-args)
cljs
(sdefn &form &env & defn-args)
source (clj)source (cljs)

toggleclj/s

(toggle b)
source

cljdoc builds & hosts documentation for Clojure/Script libraries